Name:           fritzing
Version:        0.9.2b
Release:        %mkrel 1
Summary:        Electronic Design Automation software; from prototype to product
Group:  	Sciences/Engineering 
License:        GPLv3+
URL:            http://fritzing.org/
Source0:        https://github.com/fritzing/fritzing-app/releases/%{name}-app-%{version}.tar.xz
Source1:	https://github.com/fritzing/fritzing-parts/tree/master/%{name}-parts.tar.xz
BuildRequires:	desktop-file-utils 
BuildRequires:	boost-devel
BuildRequires:	quazip-devel
BuildRequires:	ImageMagick
BuildRequires:  %{_lib}qt5base5-devel
BuildRequires:	%{_lib}qt5serialport-devel
BuildRequires:  %{_lib}qt5svg-devel
Requires:	%{_lib}qt5sql5
Requires:	%{_lib}qt5webkit5 quazip


%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based 
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{version}

# sed -i 's/\r//' README.txt
# sed -i 's/\r//' LICENSE.CC-BY-SA


%build
CXXFLAGS="%{optflags}"
%qmake_qt5 
%make

%install
# Clean
rm -rf %{buildroot}

make install INSTALL_ROOT=%{buildroot}

install -d -m 0755 %{buildroot}%{_datadir}/%{name}
tar --strip-components=1 -xf %{SOURCE1} -C %{buildroot}%{_datadir}/%{name}/parts

# A few files in /usr/share/fritzing end up executable.
find %{buildroot}%{_datadir}/%{name} -type f -exec %{__chmod} 644 {} \;
find %{buildroot}%{_datadir}/%{name} -type d -exec %{__chmod} 755 {} \;

# icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,22x22,32x32,48x48,64x64,128x128}/apps
for i in 16 22 32 48 64 128; do \
convert -resize $i\x$i resources/images/fritzing_icon.png %{buildroot}%{_iconsdir}/hicolor/$i\x$i/apps/%{name}.png
done

# resize rather large 256x256 icon
convert -resize 48\x48 %{buildroot}%{_iconsdir}/fritzing.png %{buildroot}%{_iconsdir}/fritzing.png

%__install -dm 755 %{buildroot}%{_datadir}/applications
%__cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Comment=%{summary}
Name=%{name}
GenericName=%{name}
Type=Application
MimeType=application/x-%{name}
Exec=Fritzing
Icon=%{name}
Terminal=false
Categories=Development;
EOF

# Gnome
%__install -dm 755 %{buildroot}%{_datadir}/mime/packages
cat > %{buildroot}%{_datadir}/mime/packages/application-x-%{name}.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
  <mime-type type="application/x-%{name}">
    <comment>Fritzing file type</comment>
    <glob pattern="*.fzz"/>
  </mime-type>
</mime-info>
EOF

# KDE
cat > %{buildroot}%{_datadir}/%{name}/application-x-%{name}.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
  <mime-type type="application/x-%{name}">
    <comment>Fritzing file type</comment>
    <glob pattern="*.fzz"/>
  </mime-type>
</mime-info>
EOF

%post
%update_icon_cache hicolor
xdg-mime install %{_datadir}/%{name}/application-x-%{name}.xml
xdg-mime default %{name}.desktop application/x-%{name}
gvfs-mime --set application/x-%{name} %{name}.desktop
for i in 16 22 32 48 64 128; do \
xdg-icon-resource install --context mimetypes --size $i %{_iconsdir}/hicolor/$i\x$i/apps/%{name}.png application-x-%{name}
done
update-mime-database /usr/share/mime
update-desktop-database -q

%postun
%clean_icon_cache hicolor
xdg-mime uninstall %{_datadir}/mime/application/x-%{name}.xml
for i in 16 22 32 48 64 128; do \
xdg-icon-resource uninstall --context mimetypes --size $i application-x-%{name}
done
update-mime-database /usr/share/mime
update-desktop-database -q


%files
%defattr(-,root,root,-)
%doc LICENSE.GPL2 LICENSE.GPL3 LICENSE.CC-BY-SA
%{_bindir}
%{_datadir}

%changelog
* Tue Oct 27 2015 MBantz <martin dot bantz at gmail dot com> 0.9.2b-1pclos2015
- Update to 0.9.1b
- Include parts

* Wed Jan 14 2015 MBantz <martin dot bantz at gmail dot com> 0.9.1b-1pclos2015
- Update to 0.9.1b

* Fri Sep 12 2014 MBantz <martin dot bantz at gmail dot com> 0.9.0b-3pclos2014
- Changed from qt4 to qt5 devel build requirements

* Sat Sep 06 2014 MBantz <martin dot bantz at gmail dot com> 0.9.0b-2pclos2014
- Improved icon handling

* Fri Jul 17 2014 MBantz <martin dot bantz at gmail dot com> 0.9.0b-1pclos2014
- Update to 0.9.0b
- Add mime info and icon
- Change qmake to qmake_qt4

* Fri Jan 31 2014 MBantz <martin dot bantz at gmail dot com> 0.8.7b-1pclos2014
- Update to 0.8.7b

* Sun Jan 19 2014 bb <bb> 0.8.5b-2pclos2014
- fix dependency

* Wed Jan 01 2014 MBantz <martin dot bantz at gmail dot com> 0.8.5b-1pclinuxos2014
- Adapted to PCLinux from esm at logic dot net
- Updated to 0.8.5

* Mon Nov 05 2012 Neal <nealbrks0 at gmail dot com> 0.7.10b-1pclos2012
- process

* Sat Nov 03 2012 Ken <lxgator at gmail.com> 0.7.10b-1pclos2012
- initial pkg
